@@ -283,7 +283,7 @@ void TestWordpressBuggy::error(KBlog::Blog::ErrorType type, const QString &errSt
         break;
     };
     qDebug() << "error: " << errStr;
-    if (post != 0) {
+    if (post != nullptr) {
         dumpPost(post);
     }
     qDebug() << "#############################\n";
